@@ -30,6 +30,7 @@ buffer::buffer(buffer && buf) noexcept
 	pos_ = buf.pos_;
 	buf.pos_ = nullptr;
 	size_ = buf.size_;
+	buf.size_ = 0;
 	capacity_ = buf.capacity_;
 	buf.capacity_ = 0;
 }
@@ -42,14 +43,18 @@ unsigned char* buffer::get(size_t write_size)
 			pos_ = data_;
 		}
 		else {
-			capacity_ = std::max({ size_t(1024), capacity_ * 2, capacity_ + write_size });
-			unsigned char* data = new unsigned char[capacity_];
+			if (std::numeric_limits<size_t>::max() - capacity_ < write_size) {
+				std::abort();
+			}
+			size_t const cap = std::max({ size_t(1024), capacity_ * 2, capacity_ + write_size });
+			unsigned char* d = new unsigned char[cap];
 			if (size_) {
-				memcpy(data, pos_, size_);
+				memcpy(d, pos_, size_);
 			}
 			delete[] data_;
-			data_ = data;
-			pos_ = data;
+			capacity_ = cap;
+			data_ = d;
+			pos_ = d;
 		}
 	}
 	return pos_ + size_;
@@ -58,14 +63,13 @@ unsigned char* buffer::get(size_t write_size)
 buffer& buffer::operator=(buffer const& buf)
 {
 	if (this != &buf) {
-		delete[] data_;
+		unsigned char* d{};
 		if (buf.size_) {
-			data_ = new unsigned char[buf.capacity_];
-			memcpy(data_, buf.pos_, buf.size_);
-		}
-		else {
-			data_ = nullptr;
+			d = new unsigned char[buf.capacity_];
+			memcpy(d, buf.pos_, buf.size_);
 		}
+		delete[] data_;
+		data_ = d;
 		size_ = buf.size_;
 		capacity_ = buf.capacity_;
 		pos_ = data_;
@@ -83,6 +87,7 @@ buffer& buffer::operator=(buffer && buf) noexcept
 		pos_ = buf.pos_;
 		buf.pos_ = nullptr;
 		size_ = buf.size_;
+		buf.size_ = 0;
 		capacity_ = buf.capacity_;
 		buf.capacity_ = 0;
 	}
@@ -123,8 +128,34 @@ void buffer::clear()
 
 void buffer::append(unsigned char const* data, size_t len)
 {
-	memcpy(get(len), data, len);
+	// Do the same initially as buffer::get would do, but don't delete the old pointer
+	// until after appending in case of append from own memory
+	unsigned char* old{};
+	if (capacity_ - (pos_ - data_) - size_ < len) {
+		if (capacity_ - size_ > len) {
+			memmove(data_, pos_, size_);
+			pos_ = data_;
+		}
+		else {
+			if (std::numeric_limits<size_t>::max() - capacity_ < len) {
+				std::abort();
+			}
+			size_t const cap = std::max({ size_t(1024), capacity_ * 2, capacity_ + len });
+			unsigned char* d = new unsigned char[cap];
+			if (size_) {
+				memcpy(d, pos_, size_);
+			}
+			old = data_;
+			capacity_ = cap;
+			data_ = d;
+			pos_ = d;
+		}
+	}
+
+	memcpy(pos_ + size_, data, len);
 	size_ += len;
+
+	delete [] old;
 }
 
 void buffer::append(std::string_view const& str)
@@ -134,17 +165,18 @@ void buffer::append(std::string_view const& str)
 
 void buffer::reserve(size_t capacity)
 {
-	if (capacity_ > capacity) {
+	if (capacity_ >= capacity) {
 		return;
 	}
 
-	capacity_ = std::max(size_t(1024), capacity);
-	unsigned char* data = new unsigned char[capacity_];
+	size_t const cap = std::max(size_t(1024), capacity);
+	unsigned char* d = new unsigned char[cap];
 	if (size_) {
-		memcpy(data, pos_, size_);
+		memcpy(d, pos_, size_);
 	}
 	delete[] data_;
-	data_ = data;
+	data_ = d;
+	capacity_ = cap;
 	pos_ = data_;
 }
 
