@@ -126,17 +126,18 @@ public:
 	static native_string get_link_target(native_string const& path);
 
 private:
-	// State for directory enumeration
-	bool dirs_only_{};
 
 #ifdef FZ_WINDOWS
 	WIN32_FIND_DATA m_find_data{};
 	HANDLE m_hFind{INVALID_HANDLE_VALUE};
-	bool has_next_{};
 	native_string m_find_path;
+	bool has_next_{};
 #else
 	DIR* dir_{};
 #endif
+
+	// State for directory enumeration
+	bool dirs_only_{};
 };
 
 /**
@@ -147,8 +148,17 @@ private:
  * the default permissions are used.
  *
  * This function only works with absolute paths.
+ *
+ * \param absolute_path The directory to create
+ * \param recurse If true, creation is recursive. If false, only the last segment gets
+ *                created, all other components already need to exist.
+ * \param current_user_only If true when creating the last component, its permissions will be
+ *                          restricted to the current user. Otherwise default permissions are used.
+ *                          Default permissions on  MSW this means inheriting the parent's permissions,
+ *                          on *nix the current umask is applied.
+ * \param last_created      If non-null, receives the longest sub-path that was created
  */
-result FZ_PUBLIC_SYMBOL mkdir(native_string const& absolute_path, bool recurse, bool current_user_only = false);
+result FZ_PUBLIC_SYMBOL mkdir(native_string const& absolute_path, bool recurse, bool current_user_only = false, native_string * last_created = nullptr);
 
 }
 
